@@ -3,18 +3,21 @@ from typing import List
 from .serializable import Serializable, SerializableProperty
 from enum import Enum
 
+def getFromDict(collection:"dict[str, any]", key:str, default:any = None) -> any:
+	return default if not key in collection else collection[key]
+
 class Result(Enum):
 	ok = 1
 	error = 2
 
 class Relationship(Serializable):
-	def __init__(self, id:str, type:str):
+	def __init__(self, id:str, type:str, **kwargs):
 		self.id = id
 		self.type = type
 
 # At-Home/Server
 class AtHomeServer(Serializable):
-	def __init__(self, baseUrl:str):
+	def __init__(self, baseUrl:str, **kwargs):
 		self.baseUrl = baseUrl
 		self.chapterId = None
 		super().__init__([])
@@ -35,13 +38,14 @@ class ChapterAttributes(Serializable):
 		self.createdAt = createdAt
 		self.updatedAt = updatedAt
 		self.version = version
-		self.externalUrl = None if not "externalUrl" in kwargs else kwargs["externalUrl"]
+		self.externalUrl = getFromDict(kwargs, "externalUrl")
 
 class Chapter(Serializable):
-	def __init__(self, id:str, type:str, attributes:ChapterAttributes):
+	def __init__(self, id:str, type:str, attributes:ChapterAttributes, relationships:List[Relationship], **kwargs):
 		self.id = id
 		self.type = type
 		self.attributes = attributes
+		self.relationships = relationships
 		# Instructions about how to deserialize attributes
 		super().__init__([SerializableProperty(ChapterAttributes, self.getAttributeName(self.attributes))])
 	def getPageUrls(self, atHomeServer:AtHomeServer) -> dict:
@@ -55,7 +59,7 @@ class Chapter(Serializable):
 		return output
 
 class ChapterResult(Serializable):
-	def __init__(self, result:Result, data:Chapter, relationships:List[Relationship]):
+	def __init__(self, result:Result, data:Chapter, relationships:List[Relationship], **kwargs):
 		self.result = result
 		self.data = data
 		self.relationships = relationships
@@ -68,7 +72,7 @@ class ChapterResult(Serializable):
 		raise Exception(f"ChapterResult.getMangaId() could not find a relationship to a manga for chapter {self.data.id}")
 
 class FeedResult(Serializable):
-	def __init__(self, results:List[ChapterResult], limit:int, offset:int, total:int):
+	def __init__(self, results:List[ChapterResult], limit:int, offset:int, total:int, **kwargs):
 		self.results = results
 		self.limit = limit
 		self.offset = offset
@@ -78,14 +82,14 @@ class FeedResult(Serializable):
 
 #Tags
 class TagAttributes(Serializable):
-	def __init__(self, name:dict, version:int, description:dict, group:str):
+	def __init__(self, name:dict, version:int, description:dict, group:str, **kwargs):
 		self.name = name
 		self.version = version
 		self.description = description
 		self.group = group
 		super().__init__([])
 class Tag(Serializable):
-	def __init__(self, id:str, type:str, attributes:TagAttributes):
+	def __init__(self, id:str, type:str, attributes:TagAttributes, **kwargs):
 		self.id = id
 		self.type = type
 		self.attributes = attributes
@@ -96,7 +100,7 @@ class MangaAttributes(Serializable):
 	def __init__(self, title:dict, altTitles:List[dict], description:dict, isLocked:bool, links:dict,
 				originalLanguage:str, lastVolume:str, lastChapter:str, publicationDemographic:str,
 				status:str, year:int, contentRating:str, tags:List[Tag], createdAt:str, updatedAt:str,
-				version:int, modNotes:str=None):
+				version:int, modNotes:str=None, **kwargs):
 		self.title = title
 		self.altTitles = altTitles
 		self.description = description
@@ -117,21 +121,21 @@ class MangaAttributes(Serializable):
 		super().__init__([SerializableProperty(Tag, self.getAttributeName(self.tags))])
 
 class Manga(Serializable):
-	def __init__(self, id:str, type:str, attributes:MangaAttributes):
+	def __init__(self, id:str, type:str, attributes:MangaAttributes, **kwargs):
 		self.id = id
 		self.type = type
 		self.attributes = attributes
 		super().__init__([SerializableProperty(MangaAttributes, self.getAttributeName(self.attributes))])
 
 class MangaResult(Serializable):
-	def __init__(self, result:Result, data:Manga, relationships:List[Relationship]):
+	def __init__(self, result:Result, data:Manga, relationships:List[Relationship], **kwargs):
 		self.result = result
 		self.data = data
 		self.relationships = relationships
 		super().__init__([SerializableProperty(Manga, self.getAttributeName(self.data)), SerializableProperty(Relationship, self.getAttributeName(self.relationships))])
 
 class MangaListResult(Serializable):
-	def __init__(self, results:List[MangaResult], limit:int, offset:int, total:int):
+	def __init__(self, results:List[MangaResult], limit:int, offset:int, total:int, **kwargs):
 		self.results = results
 		self.limit = limit
 		self.offset = offset
@@ -141,7 +145,7 @@ class MangaListResult(Serializable):
 
 # Authors
 class AuthorAttributes(Serializable):
-	def __init__(self, name:str, imageUrl:str, biography:List[dict], createdAt:str, updatedAt:str, version:int):
+	def __init__(self, name:str, imageUrl:str, biography:List[dict], createdAt:str, updatedAt:str, version:int, **kwargs):
 		self.name = name
 		self.imageUrl = imageUrl
 		self.biography = biography
@@ -150,20 +154,20 @@ class AuthorAttributes(Serializable):
 		self.version = version
 		super().__init__([])
 class Author(Serializable):
-	def __init__(self, id:str, type:str, attributes:AuthorAttributes):
+	def __init__(self, id:str, type:str, attributes:AuthorAttributes, **kwargs):
 		self.id = id
 		self.type = type
 		self.attributes = attributes
 		super().__init__([SerializableProperty(AuthorAttributes, self.getAttributeName(self.attributes))])
 class AuthorResult(Serializable):
-	def __init__(self, result:Result, data:Author, relationships:List[Relationship]):
+	def __init__(self, result:Result, data:Author, relationships:List[Relationship], **kwargs):
 		self.result = result
 		self.data = data
 		self.relationships = relationships
 		super().__init__([SerializableProperty(Author, self.getAttributeName(self.data)), SerializableProperty(Relationship, self.getAttributeName(self.relationships))])
 
 class AuthorListResult(Serializable):
-	def __init__(self, results:List[AuthorResult], limit:int, offset:int, total:int):
+	def __init__(self, results:List[AuthorResult], limit:int, offset:int, total:int, **kwargs):
 		self.results = results
 		self.limit = limit
 		self.offset = offset
